
## CATO-CLI - mutation.sites.removeStaticHost:
[Click here](https://api.catonetworks.com/documentation/#mutation-mutation.sites.removeStaticHost) for documentation on this operation.

### Usage for mutation.sites.removeStaticHost:

```bash
catocli mutation sites removeStaticHost -h

catocli mutation sites removeStaticHost <json>

catocli mutation sites removeStaticHost --json-file mutation.sites.removeStaticHost.json

catocli mutation sites removeStaticHost '{"hostId":"id"}'

catocli mutation sites removeStaticHost '{
    "hostId": "id"
}'
```

#### Operation Arguments for mutation.sites.removeStaticHost ####

`accountId` [ID] - (required) N/A    
`hostId` [ID] - (required) N/A    
